summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJonathan Kim <jkm@hdfgroup.org>2010-05-21 20:12:22 (GMT)
committerJonathan Kim <jkm@hdfgroup.org>2010-05-21 20:12:22 (GMT)
commita5ca9e6ba9f8588ca1a2cc2b88885a54ea3d27f8 (patch)
tree2d2fc8b735fee3361886acb1455469384b33cbfb
parentff334a5952d524660e4d4c82ad823c16c8696bfd (diff)
downloadhdf5-a5ca9e6ba9f8588ca1a2cc2b88885a54ea3d27f8.zip
hdf5-a5ca9e6ba9f8588ca1a2cc2b88885a54ea3d27f8.tar.gz
hdf5-a5ca9e6ba9f8588ca1a2cc2b88885a54ea3d27f8.tar.bz2
[svn-r18873] Purpose:
Rename '--follow-links' to '--follow-symlinks' Description: The '--follow-links' option is to follow symbolic links (soft and external). Make the name more intuitive and specific to the feature. Tested: jam, amani and linew
-rw-r--r--release_docs/RELEASE.txt2
-rw-r--r--tools/h5diff/CMakeLists.txt82
-rw-r--r--tools/h5diff/h5diff_common.c12
-rw-r--r--tools/h5diff/testfiles/h5diff_10.txt10
-rw-r--r--tools/h5diff/testfiles/h5diff_452.txt2
-rw-r--r--tools/h5diff/testfiles/h5diff_600.txt10
-rw-r--r--tools/h5diff/testfiles/h5diff_603.txt10
-rw-r--r--tools/h5diff/testfiles/h5diff_606.txt10
-rw-r--r--tools/h5diff/testfiles/h5diff_612.txt10
-rw-r--r--tools/h5diff/testfiles/h5diff_615.txt10
-rw-r--r--tools/h5diff/testfiles/h5diff_621.txt10
-rw-r--r--tools/h5diff/testfiles/h5diff_622.txt10
-rw-r--r--tools/h5diff/testfiles/h5diff_623.txt10
-rw-r--r--tools/h5diff/testfiles/h5diff_624.txt10
-rwxr-xr-xtools/h5diff/testh5diff.sh84
-rw-r--r--tools/lib/h5diff.c4
16 files changed, 143 insertions, 143 deletions
diff --git a/release_docs/RELEASE.txt b/release_docs/RELEASE.txt
index 13807dc..469ca38 100644
--- a/release_docs/RELEASE.txt
+++ b/release_docs/RELEASE.txt
@@ -161,7 +161,7 @@ New Features
------
- h5diff: Add new flag --no-dangling-links. (refer to --help for details)
(JKM - 2010/02/10)
- - h5diff: Add new flag --follow-links. (refer to --help for details)
+ - h5diff: Add new flag --follow-symlinks. (refer to --help for details)
(JKM - 2010/01/25)
- h5diff: fix for displaying garbage value on LE machine for BE data.
(JKM - 2009/11/20)
diff --git a/tools/h5diff/CMakeLists.txt b/tools/h5diff/CMakeLists.txt
index 8f4a9bd..04a9102 100644
--- a/tools/h5diff/CMakeLists.txt
+++ b/tools/h5diff/CMakeLists.txt
@@ -521,125 +521,125 @@ ADD_H5_TEST (h5diff_206 0 -c ${FILE2} ${FILE2} g2/dset7 g2/dset8)
ADD_H5_TEST (h5diff_207 0 -c ${FILE2} ${FILE2} g2/dset8 g2/dset9)
# ##############################################################################
-# # Links compare without --follow-links nor --no-dangling-links
+# # Links compare without --follow-symlinks nor --no-dangling-links
# ##############################################################################
# test for bug1749
ADD_H5_TEST (h5diff_300 1 -v ${FILE12} ${FILE12} /link_g1 /link_g2)
# ##############################################################################
-# # Links compare with --follow-links Only
+# # Links compare with --follow-symlinks Only
# ##############################################################################
# soft links file to file
-ADD_H5_TEST (h5diff_400 0 --follow-links -v ${FILE13} ${FILE13})
+ADD_H5_TEST (h5diff_400 0 --follow-symlinks -v ${FILE13} ${FILE13})
# softlink vs dset"
-ADD_H5_TEST (h5diff_401 1 --follow-links -v ${FILE13} ${FILE13} /softlink_dset1_1 /target_dset2)
+ADD_H5_TEST (h5diff_401 1 --follow-symlinks -v ${FILE13} ${FILE13} /softlink_dset1_1 /target_dset2)
# dset vs softlink"
-ADD_H5_TEST (h5diff_402 1 --follow-links -v ${FILE13} ${FILE13} /target_dset2 /softlink_dset1_1)
+ADD_H5_TEST (h5diff_402 1 --follow-symlinks -v ${FILE13} ${FILE13} /target_dset2 /softlink_dset1_1)
# softlink vs softlink"
-ADD_H5_TEST (h5diff_403 1 --follow-links -v ${FILE13} ${FILE13} /softlink_dset1_1 /softlink_dset2)
+ADD_H5_TEST (h5diff_403 1 --follow-symlinks -v ${FILE13} ${FILE13} /softlink_dset1_1 /softlink_dset2)
# extlink vs extlink (FILE)"
-ADD_H5_TEST (h5diff_404 0 --follow-links -v ${FILE15} ${FILE15})
+ADD_H5_TEST (h5diff_404 0 --follow-symlinks -v ${FILE15} ${FILE15})
# extlink vs dset"
-ADD_H5_TEST (h5diff_405 1 --follow-links -v ${FILE15} ${FILE16} /ext_link_dset1 /target_group2/x_dset)
+ADD_H5_TEST (h5diff_405 1 --follow-symlinks -v ${FILE15} ${FILE16} /ext_link_dset1 /target_group2/x_dset)
# dset vs extlink"
-ADD_H5_TEST (h5diff_406 1 --follow-links -v ${FILE16} ${FILE15} /target_group2/x_dset /ext_link_dset1)
+ADD_H5_TEST (h5diff_406 1 --follow-symlinks -v ${FILE16} ${FILE15} /target_group2/x_dset /ext_link_dset1)
# extlink vs extlink"
-ADD_H5_TEST (h5diff_407 1 --follow-links -v ${FILE15} ${FILE15} /ext_link_dset1 /ext_link_dset2)
+ADD_H5_TEST (h5diff_407 1 --follow-symlinks -v ${FILE15} ${FILE15} /ext_link_dset1 /ext_link_dset2)
# softlink vs extlink"
-ADD_H5_TEST (h5diff_408 1 --follow-links -v ${FILE13} ${FILE15} /softlink_dset1_1 /ext_link_dset2)
+ADD_H5_TEST (h5diff_408 1 --follow-symlinks -v ${FILE13} ${FILE15} /softlink_dset1_1 /ext_link_dset2)
# extlink vs softlink "
-ADD_H5_TEST (h5diff_409 1 --follow-links -v ${FILE15} ${FILE13} /ext_link_dset2 /softlink_dset1_1)
+ADD_H5_TEST (h5diff_409 1 --follow-symlinks -v ${FILE15} ${FILE13} /ext_link_dset2 /softlink_dset1_1)
# linked_softlink vs linked_softlink (FILE)"
-ADD_H5_TEST (h5diff_410 0 --follow-links -v ${FILE14} ${FILE14})
+ADD_H5_TEST (h5diff_410 0 --follow-symlinks -v ${FILE14} ${FILE14})
# dset2 vs linked_softlink_dset1"
-ADD_H5_TEST (h5diff_411 1 --follow-links -v ${FILE14} ${FILE14} /target_dset2 /softlink1_to_slink2)
+ADD_H5_TEST (h5diff_411 1 --follow-symlinks -v ${FILE14} ${FILE14} /target_dset2 /softlink1_to_slink2)
# linked_softlink_dset1 vs dset2"
-ADD_H5_TEST (h5diff_412 1 --follow-links -v ${FILE14} ${FILE14} /softlink1_to_slink2 /target_dset2)
+ADD_H5_TEST (h5diff_412 1 --follow-symlinks -v ${FILE14} ${FILE14} /softlink1_to_slink2 /target_dset2)
# linked_softlink_to_dset1 vs linked_softlink_to_dset2"
-ADD_H5_TEST (h5diff_413 1 --follow-links -v ${FILE14} ${FILE14} /softlink1_to_slink2 /softlink2_to_slink2)
+ADD_H5_TEST (h5diff_413 1 --follow-symlinks -v ${FILE14} ${FILE14} /softlink1_to_slink2 /softlink2_to_slink2)
# group vs linked_softlink_group1"
-ADD_H5_TEST (h5diff_414 1 --follow-links -v ${FILE14} ${FILE14} /target_group /softlink3_to_slink2)
+ADD_H5_TEST (h5diff_414 1 --follow-symlinks -v ${FILE14} ${FILE14} /target_group /softlink3_to_slink2)
# linked_softlink_group1 vs group"
-ADD_H5_TEST (h5diff_415 1 --follow-links -v ${FILE14} ${FILE14} /softlink3_to_slink2 /target_group)
+ADD_H5_TEST (h5diff_415 1 --follow-symlinks -v ${FILE14} ${FILE14} /softlink3_to_slink2 /target_group)
# linked_softlink_to_group1 vs linked_softlink_to_group2"
-ADD_H5_TEST (h5diff_416 1 --follow-links -v ${FILE14} ${FILE14} /softlink3_to_slink2 /softlink4_to_slink2)
+ADD_H5_TEST (h5diff_416 1 --follow-symlinks -v ${FILE14} ${FILE14} /softlink3_to_slink2 /softlink4_to_slink2)
# non-exist-softlink vs softlink"
-ADD_H5_TEST (h5diff_417 1 --follow-links -v ${FILE13} ${FILE13} /softlink_noexist /softlink_dset2)
+ADD_H5_TEST (h5diff_417 1 --follow-symlinks -v ${FILE13} ${FILE13} /softlink_noexist /softlink_dset2)
# softlink vs non-exist-softlink"
-ADD_H5_TEST (h5diff_418 1 --follow-links -v ${FILE13} ${FILE13} /softlink_dset2 /softlink_noexist)
+ADD_H5_TEST (h5diff_418 1 --follow-symlinks -v ${FILE13} ${FILE13} /softlink_dset2 /softlink_noexist)
# non-exist-extlink_file vs extlink"
-ADD_H5_TEST (h5diff_419 1 --follow-links -v ${FILE15} ${FILE15} /ext_link_noexist2 /ext_link_dset2)
+ADD_H5_TEST (h5diff_419 1 --follow-symlinks -v ${FILE15} ${FILE15} /ext_link_noexist2 /ext_link_dset2)
# exlink vs non-exist-extlink_file"
-ADD_H5_TEST (h5diff_420 1 --follow-links -v ${FILE15} ${FILE15} /ext_link_dset2 /ext_link_noexist2)
+ADD_H5_TEST (h5diff_420 1 --follow-symlinks -v ${FILE15} ${FILE15} /ext_link_dset2 /ext_link_noexist2)
# extlink vs non-exist-extlink_obj"
-ADD_H5_TEST (h5diff_421 1 --follow-links -v ${FILE15} ${FILE15} /ext_link_dset2 /ext_link_noexist1)
+ADD_H5_TEST (h5diff_421 1 --follow-symlinks -v ${FILE15} ${FILE15} /ext_link_dset2 /ext_link_noexist1)
# non-exist-extlink_obj vs extlink"
-ADD_H5_TEST (h5diff_422 1 --follow-links -v ${FILE15} ${FILE15} /ext_link_noexist1 /ext_link_dset2)
+ADD_H5_TEST (h5diff_422 1 --follow-symlinks -v ${FILE15} ${FILE15} /ext_link_noexist1 /ext_link_dset2)
# extlink_to_softlink_to_dset1 vs dset2"
-ADD_H5_TEST (h5diff_423 1 --follow-links -v ${FILE17} ${FILE18} /ext_link_to_slink1 /dset2)
+ADD_H5_TEST (h5diff_423 1 --follow-symlinks -v ${FILE17} ${FILE18} /ext_link_to_slink1 /dset2)
# dset2 vs extlink_to_softlink_to_dset1"
-ADD_H5_TEST (h5diff_424 1 --follow-links -v ${FILE18} ${FILE17} /dset2 /ext_link_to_slink1)
+ADD_H5_TEST (h5diff_424 1 --follow-symlinks -v ${FILE18} ${FILE17} /dset2 /ext_link_to_slink1)
# extlink_to_softlink_to_dset1 vs extlink_to_softlink_to_dset2"
-ADD_H5_TEST (h5diff_425 1 --follow-links -v ${FILE17} ${FILE17} /ext_link_to_slink1 /ext_link_to_slink2)
+ADD_H5_TEST (h5diff_425 1 --follow-symlinks -v ${FILE17} ${FILE17} /ext_link_to_slink1 /ext_link_to_slink2)
# ##############################################################################
-# # Dangling links compare (--follow-links and --no-dangling-links)
+# # Dangling links compare (--follow-symlinks and --no-dangling-links)
# ##############################################################################
-# dangling links --follow-links (FILE to FILE)
-ADD_H5_TEST (h5diff_450 1 --follow-links -v ${DANGLE_LINK_FILE1} ${DANGLE_LINK_FILE2})
+# dangling links --follow-symlinks (FILE to FILE)
+ADD_H5_TEST (h5diff_450 1 --follow-symlinks -v ${DANGLE_LINK_FILE1} ${DANGLE_LINK_FILE2})
-# dangling links --follow-links and --no-dangling-links (FILE to FILE)
-ADD_H5_TEST (h5diff_451 2 --follow-links -v --no-dangling-links ${DANGLE_LINK_FILE1} ${DANGLE_LINK_FILE2})
+# dangling links --follow-symlinks and --no-dangling-links (FILE to FILE)
+ADD_H5_TEST (h5diff_451 2 --follow-symlinks -v --no-dangling-links ${DANGLE_LINK_FILE1} ${DANGLE_LINK_FILE2})
-# try --no-dangling-links without --follow-links options
+# try --no-dangling-links without --follow-symlinks options
ADD_H5_TEST (h5diff_452 2 --no-dangling-links ${FILE13} ${FILE13})
# dangling link found for soft links (FILE to FILE)
-ADD_H5_TEST (h5diff_453 2 --follow-links -v --no-dangling-links ${FILE13} ${FILE13})
+ADD_H5_TEST (h5diff_453 2 --follow-symlinks -v --no-dangling-links ${FILE13} ${FILE13})
# dangling link found for soft links (obj to obj)
-ADD_H5_TEST (h5diff_454 2 --follow-links -v --no-dangling-links ${FILE13} ${FILE13} /softlink_dset2 /softlink_noexist)
+ADD_H5_TEST (h5diff_454 2 --follow-symlinks -v --no-dangling-links ${FILE13} ${FILE13} /softlink_dset2 /softlink_noexist)
# dangling link found for soft links (obj to obj) Both dangle links
-ADD_H5_TEST (h5diff_455 2 --follow-links -v --no-dangling-links ${FILE13} ${FILE13} /softlink_noexist /softlink_noexist)
+ADD_H5_TEST (h5diff_455 2 --follow-symlinks -v --no-dangling-links ${FILE13} ${FILE13} /softlink_noexist /softlink_noexist)
# dangling link found for ext links (FILE to FILE)
-ADD_H5_TEST (h5diff_456 2 --follow-links -v --no-dangling-links ${FILE15} ${FILE15})
+ADD_H5_TEST (h5diff_456 2 --follow-symlinks -v --no-dangling-links ${FILE15} ${FILE15})
# dangling link found for ext links (obj to obj). target file exist
-ADD_H5_TEST (h5diff_457 2 --follow-links -v --no-dangling-links ${FILE15} ${FILE15} /ext_link_dset1 /ext_link_noexist1)
+ADD_H5_TEST (h5diff_457 2 --follow-symlinks -v --no-dangling-links ${FILE15} ${FILE15} /ext_link_dset1 /ext_link_noexist1)
# dangling link found for ext links (obj to obj). target file NOT exist
-ADD_H5_TEST (h5diff_458 2 --follow-links -v --no-dangling-links ${FILE15} ${FILE15} /ext_link_dset1 /ext_link_noexist2)
+ADD_H5_TEST (h5diff_458 2 --follow-symlinks -v --no-dangling-links ${FILE15} ${FILE15} /ext_link_dset1 /ext_link_noexist2)
# dangling link found for ext links (obj to obj). Both dangle links
-ADD_H5_TEST (h5diff_459 2 --follow-links -v --no-dangling-links ${FILE15} ${FILE15} /ext_link_noexist1 /ext_link_noexist2)
+ADD_H5_TEST (h5diff_459 2 --follow-symlinks -v --no-dangling-links ${FILE15} ${FILE15} /ext_link_noexist1 /ext_link_noexist2)
ENDIF (BUILD_TESTING)
diff --git a/tools/h5diff/h5diff_common.c b/tools/h5diff/h5diff_common.c
index cf54a35..9b6037e 100644
--- a/tools/h5diff/h5diff_common.c
+++ b/tools/h5diff/h5diff_common.c
@@ -40,7 +40,7 @@ static struct long_options l_opts[] = {
{ "nan", no_arg, 'N' },
{ "compare", no_arg, 'c' },
{ "use-system-epsilon", no_arg, 'e' },
- { "follow-links", no_arg, 'l' },
+ { "follow-symlinks", no_arg, 'l' },
{ "no-dangling-links", no_arg, 'x' },
{ NULL, 0, '\0' }
};
@@ -363,7 +363,7 @@ void usage(void)
printf(" -r, --report Report mode. Print differences.\n");
printf(" -v, --verbose Verbose mode. Print differences, list of objects.\n");
printf(" -q, --quiet Quiet mode. Do not produce output.\n");
- printf(" --follow-links Follow symbolic links (soft links and external links)\n");
+ printf(" --follow-symlinks Follow symbolic links (soft links and external links)\n");
printf(" and compare the links' target objects.\n");
printf(" If symbolic link(s) with the same name exist in the\n");
printf(" files being compared, then determine whether the \n");
@@ -374,13 +374,13 @@ void usage(void)
printf(" - If both symbolic links are dangling links, they\n");
printf(" are treated as being the same; by default, h5diff\n");
printf(" returns an exit code of 0. If, however, \n");
- printf(" --no-dangling-links is used with --follow-links, \n");
+ printf(" --no-dangling-links is used with --follow-symlinks,\n");
printf(" this situation is treated as an error and h5diff \n");
printf(" returns an exit code of 2.\n");
printf(" - If only one of the two links is a dangling link,\n");
printf(" they are treated as being different and h5diff \n");
printf(" returns an exit code of 1. If, however, \n");
- printf(" --no-dangling-links is used with --follow-links, \n");
+ printf(" --no-dangling-links is used with --follow-symlinks,\n");
printf(" this situation is treated as an error and h5diff \n");
printf(" returns an exit code of 2.\n");
printf(" - If both symbolic links point to existing objects,\n");
@@ -388,7 +388,7 @@ void usage(void)
printf(" If any symbolic link specified in the call to h5diff\n");
printf(" does not exist, h5diff treats it as an error and\n");
printf(" returns an exit code of 2.\n");
- printf(" --no-dangling-links Must be used with --follow-links option;\n");
+ printf(" --no-dangling-links Must be used with --follow-symlinks option;\n");
printf(" otherwise, h5diff shows error message and returns\n");
printf(" an exit code of 2.\n");
printf(" Check for any symbolic links (soft links or external\n");
@@ -435,7 +435,7 @@ void usage(void)
printf(" 2) groups: name string difference\n");
printf(" 3) datatypes: the return value of H5Tequal\n");
printf(" 4) links: name string difference of the linked value as default\n");
- printf(" (refer to --follow-links option).\n");
+ printf(" (refer to --follow-symlinks option).\n");
printf("\n");
printf(" Exit code:\n");
printf(" 0 if no differences, 1 if differences found, 2 if error\n");
diff --git a/tools/h5diff/testfiles/h5diff_10.txt b/tools/h5diff/testfiles/h5diff_10.txt
index aeba845..d3ee9a6 100644
--- a/tools/h5diff/testfiles/h5diff_10.txt
+++ b/tools/h5diff/testfiles/h5diff_10.txt
@@ -10,7 +10,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
-r, --report Report mode. Print differences.
-v, --verbose Verbose mode. Print differences, list of objects.
-q, --quiet Quiet mode. Do not produce output.
- --follow-links Follow symbolic links (soft links and external links)
+ --follow-symlinks Follow symbolic links (soft links and external links)
and compare the links' target objects.
If symbolic link(s) with the same name exist in the
files being compared, then determine whether the
@@ -21,13 +21,13 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
- If both symbolic links are dangling links, they
are treated as being the same; by default, h5diff
returns an exit code of 0. If, however,
- --no-dangling-links is used with --follow-links,
+ --no-dangling-links is used with --follow-symlinks,
this situation is treated as an error and h5diff
returns an exit code of 2.
- If only one of the two links is a dangling link,
they are treated as being different and h5diff
returns an exit code of 1. If, however,
- --no-dangling-links is used with --follow-links,
+ --no-dangling-links is used with --follow-symlinks,
this situation is treated as an error and h5diff
returns an exit code of 2.
- If both symbolic links point to existing objects,
@@ -35,7 +35,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
If any symbolic link specified in the call to h5diff
does not exist, h5diff treats it as an error and
returns an exit code of 2.
- --no-dangling-links Must be used with --follow-links option;
+ --no-dangling-links Must be used with --follow-symlinks option;
otherwise, h5diff shows error message and returns
an exit code of 2.
Check for any symbolic links (soft links or external
@@ -78,7 +78,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
2) groups: name string difference
3) datatypes: the return value of H5Tequal
4) links: name string difference of the linked value as default
- (refer to --follow-links option).
+ (refer to --follow-symlinks option).
Exit code:
0 if no differences, 1 if differences found, 2 if error
diff --git a/tools/h5diff/testfiles/h5diff_452.txt b/tools/h5diff/testfiles/h5diff_452.txt
index 76e4457..05403af 100644
--- a/tools/h5diff/testfiles/h5diff_452.txt
+++ b/tools/h5diff/testfiles/h5diff_452.txt
@@ -1,2 +1,2 @@
-Error: --no-dangling-links must be used along with --follow-links option.
+Error: --no-dangling-links must be used along with --follow-symlinks option.
EXIT CODE: 2
diff --git a/tools/h5diff/testfiles/h5diff_600.txt b/tools/h5diff/testfiles/h5diff_600.txt
index f76d4d5..cf540ab 100644
--- a/tools/h5diff/testfiles/h5diff_600.txt
+++ b/tools/h5diff/testfiles/h5diff_600.txt
@@ -10,7 +10,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
-r, --report Report mode. Print differences.
-v, --verbose Verbose mode. Print differences, list of objects.
-q, --quiet Quiet mode. Do not produce output.
- --follow-links Follow symbolic links (soft links and external links)
+ --follow-symlinks Follow symbolic links (soft links and external links)
and compare the links' target objects.
If symbolic link(s) with the same name exist in the
files being compared, then determine whether the
@@ -21,13 +21,13 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
- If both symbolic links are dangling links, they
are treated as being the same; by default, h5diff
returns an exit code of 0. If, however,
- --no-dangling-links is used with --follow-links,
+ --no-dangling-links is used with --follow-symlinks,
this situation is treated as an error and h5diff
returns an exit code of 2.
- If only one of the two links is a dangling link,
they are treated as being different and h5diff
returns an exit code of 1. If, however,
- --no-dangling-links is used with --follow-links,
+ --no-dangling-links is used with --follow-symlinks,
this situation is treated as an error and h5diff
returns an exit code of 2.
- If both symbolic links point to existing objects,
@@ -35,7 +35,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
If any symbolic link specified in the call to h5diff
does not exist, h5diff treats it as an error and
returns an exit code of 2.
- --no-dangling-links Must be used with --follow-links option;
+ --no-dangling-links Must be used with --follow-symlinks option;
otherwise, h5diff shows error message and returns
an exit code of 2.
Check for any symbolic links (soft links or external
@@ -78,7 +78,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
2) groups: name string difference
3) datatypes: the return value of H5Tequal
4) links: name string difference of the linked value as default
- (refer to --follow-links option).
+ (refer to --follow-symlinks option).
Exit code:
0 if no differences, 1 if differences found, 2 if error
diff --git a/tools/h5diff/testfiles/h5diff_603.txt b/tools/h5diff/testfiles/h5diff_603.txt
index a5286df..2f2e93f 100644
--- a/tools/h5diff/testfiles/h5diff_603.txt
+++ b/tools/h5diff/testfiles/h5diff_603.txt
@@ -11,7 +11,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
-r, --report Report mode. Print differences.
-v, --verbose Verbose mode. Print differences, list of objects.
-q, --quiet Quiet mode. Do not produce output.
- --follow-links Follow symbolic links (soft links and external links)
+ --follow-symlinks Follow symbolic links (soft links and external links)
and compare the links' target objects.
If symbolic link(s) with the same name exist in the
files being compared, then determine whether the
@@ -22,13 +22,13 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
- If both symbolic links are dangling links, they
are treated as being the same; by default, h5diff
returns an exit code of 0. If, however,
- --no-dangling-links is used with --follow-links,
+ --no-dangling-links is used with --follow-symlinks,
this situation is treated as an error and h5diff
returns an exit code of 2.
- If only one of the two links is a dangling link,
they are treated as being different and h5diff
returns an exit code of 1. If, however,
- --no-dangling-links is used with --follow-links,
+ --no-dangling-links is used with --follow-symlinks,
this situation is treated as an error and h5diff
returns an exit code of 2.
- If both symbolic links point to existing objects,
@@ -36,7 +36,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
If any symbolic link specified in the call to h5diff
does not exist, h5diff treats it as an error and
returns an exit code of 2.
- --no-dangling-links Must be used with --follow-links option;
+ --no-dangling-links Must be used with --follow-symlinks option;
otherwise, h5diff shows error message and returns
an exit code of 2.
Check for any symbolic links (soft links or external
@@ -79,7 +79,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
2) groups: name string difference
3) datatypes: the return value of H5Tequal
4) links: name string difference of the linked value as default
- (refer to --follow-links option).
+ (refer to --follow-symlinks option).
Exit code:
0 if no differences, 1 if differences found, 2 if error
diff --git a/tools/h5diff/testfiles/h5diff_606.txt b/tools/h5diff/testfiles/h5diff_606.txt
index ab8039e..3381406 100644
--- a/tools/h5diff/testfiles/h5diff_606.txt
+++ b/tools/h5diff/testfiles/h5diff_606.txt
@@ -11,7 +11,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
-r, --report Report mode. Print differences.
-v, --verbose Verbose mode. Print differences, list of objects.
-q, --quiet Quiet mode. Do not produce output.
- --follow-links Follow symbolic links (soft links and external links)
+ --follow-symlinks Follow symbolic links (soft links and external links)
and compare the links' target objects.
If symbolic link(s) with the same name exist in the
files being compared, then determine whether the
@@ -22,13 +22,13 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
- If both symbolic links are dangling links, they
are treated as being the same; by default, h5diff
returns an exit code of 0. If, however,
- --no-dangling-links is used with --follow-links,
+ --no-dangling-links is used with --follow-symlinks,
this situation is treated as an error and h5diff
returns an exit code of 2.
- If only one of the two links is a dangling link,
they are treated as being different and h5diff
returns an exit code of 1. If, however,
- --no-dangling-links is used with --follow-links,
+ --no-dangling-links is used with --follow-symlinks,
this situation is treated as an error and h5diff
returns an exit code of 2.
- If both symbolic links point to existing objects,
@@ -36,7 +36,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
If any symbolic link specified in the call to h5diff
does not exist, h5diff treats it as an error and
returns an exit code of 2.
- --no-dangling-links Must be used with --follow-links option;
+ --no-dangling-links Must be used with --follow-symlinks option;
otherwise, h5diff shows error message and returns
an exit code of 2.
Check for any symbolic links (soft links or external
@@ -79,7 +79,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
2) groups: name string difference
3) datatypes: the return value of H5Tequal
4) links: name string difference of the linked value as default
- (refer to --follow-links option).
+ (refer to --follow-symlinks option).
Exit code:
0 if no differences, 1 if differences found, 2 if error
diff --git a/tools/h5diff/testfiles/h5diff_612.txt b/tools/h5diff/testfiles/h5diff_612.txt
index 686ff15..8c6051e 100644
--- a/tools/h5diff/testfiles/h5diff_612.txt
+++ b/tools/h5diff/testfiles/h5diff_612.txt
@@ -11,7 +11,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
-r, --report Report mode. Print differences.
-v, --verbose Verbose mode. Print differences, list of objects.
-q, --quiet Quiet mode. Do not produce output.
- --follow-links Follow symbolic links (soft links and external links)
+ --follow-symlinks Follow symbolic links (soft links and external links)
and compare the links' target objects.
If symbolic link(s) with the same name exist in the
files being compared, then determine whether the
@@ -22,13 +22,13 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
- If both symbolic links are dangling links, they
are treated as being the same; by default, h5diff
returns an exit code of 0. If, however,
- --no-dangling-links is used with --follow-links,
+ --no-dangling-links is used with --follow-symlinks,
this situation is treated as an error and h5diff
returns an exit code of 2.
- If only one of the two links is a dangling link,
they are treated as being different and h5diff
returns an exit code of 1. If, however,
- --no-dangling-links is used with --follow-links,
+ --no-dangling-links is used with --follow-symlinks,
this situation is treated as an error and h5diff
returns an exit code of 2.
- If both symbolic links point to existing objects,
@@ -36,7 +36,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
If any symbolic link specified in the call to h5diff
does not exist, h5diff treats it as an error and
returns an exit code of 2.
- --no-dangling-links Must be used with --follow-links option;
+ --no-dangling-links Must be used with --follow-symlinks option;
otherwise, h5diff shows error message and returns
an exit code of 2.
Check for any symbolic links (soft links or external
@@ -79,7 +79,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
2) groups: name string difference
3) datatypes: the return value of H5Tequal
4) links: name string difference of the linked value as default
- (refer to --follow-links option).
+ (refer to --follow-symlinks option).
Exit code:
0 if no differences, 1 if differences found, 2 if error
diff --git a/tools/h5diff/testfiles/h5diff_615.txt b/tools/h5diff/testfiles/h5diff_615.txt
index cf779c5..b713c7b 100644
--- a/tools/h5diff/testfiles/h5diff_615.txt
+++ b/tools/h5diff/testfiles/h5diff_615.txt
@@ -11,7 +11,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
-r, --report Report mode. Print differences.
-v, --verbose Verbose mode. Print differences, list of objects.
-q, --quiet Quiet mode. Do not produce output.
- --follow-links Follow symbolic links (soft links and external links)
+ --follow-symlinks Follow symbolic links (soft links and external links)
and compare the links' target objects.
If symbolic link(s) with the same name exist in the
files being compared, then determine whether the
@@ -22,13 +22,13 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
- If both symbolic links are dangling links, they
are treated as being the same; by default, h5diff
returns an exit code of 0. If, however,
- --no-dangling-links is used with --follow-links,
+ --no-dangling-links is used with --follow-symlinks,
this situation is treated as an error and h5diff
returns an exit code of 2.
- If only one of the two links is a dangling link,
they are treated as being different and h5diff
returns an exit code of 1. If, however,
- --no-dangling-links is used with --follow-links,
+ --no-dangling-links is used with --follow-symlinks,
this situation is treated as an error and h5diff
returns an exit code of 2.
- If both symbolic links point to existing objects,
@@ -36,7 +36,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
If any symbolic link specified in the call to h5diff
does not exist, h5diff treats it as an error and
returns an exit code of 2.
- --no-dangling-links Must be used with --follow-links option;
+ --no-dangling-links Must be used with --follow-symlinks option;
otherwise, h5diff shows error message and returns
an exit code of 2.
Check for any symbolic links (soft links or external
@@ -79,7 +79,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
2) groups: name string difference
3) datatypes: the return value of H5Tequal
4) links: name string difference of the linked value as default
- (refer to --follow-links option).
+ (refer to --follow-symlinks option).
Exit code:
0 if no differences, 1 if differences found, 2 if error
diff --git a/tools/h5diff/testfiles/h5diff_621.txt b/tools/h5diff/testfiles/h5diff_621.txt
index 041bb7b..ee23b90 100644
--- a/tools/h5diff/testfiles/h5diff_621.txt
+++ b/tools/h5diff/testfiles/h5diff_621.txt
@@ -11,7 +11,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
-r, --report Report mode. Print differences.
-v, --verbose Verbose mode. Print differences, list of objects.
-q, --quiet Quiet mode. Do not produce output.
- --follow-links Follow symbolic links (soft links and external links)
+ --follow-symlinks Follow symbolic links (soft links and external links)
and compare the links' target objects.
If symbolic link(s) with the same name exist in the
files being compared, then determine whether the
@@ -22,13 +22,13 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
- If both symbolic links are dangling links, they
are treated as being the same; by default, h5diff
returns an exit code of 0. If, however,
- --no-dangling-links is used with --follow-links,
+ --no-dangling-links is used with --follow-symlinks,
this situation is treated as an error and h5diff
returns an exit code of 2.
- If only one of the two links is a dangling link,
they are treated as being different and h5diff
returns an exit code of 1. If, however,
- --no-dangling-links is used with --follow-links,
+ --no-dangling-links is used with --follow-symlinks,
this situation is treated as an error and h5diff
returns an exit code of 2.
- If both symbolic links point to existing objects,
@@ -36,7 +36,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
If any symbolic link specified in the call to h5diff
does not exist, h5diff treats it as an error and
returns an exit code of 2.
- --no-dangling-links Must be used with --follow-links option;
+ --no-dangling-links Must be used with --follow-symlinks option;
otherwise, h5diff shows error message and returns
an exit code of 2.
Check for any symbolic links (soft links or external
@@ -79,7 +79,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
2) groups: name string difference
3) datatypes: the return value of H5Tequal
4) links: name string difference of the linked value as default
- (refer to --follow-links option).
+ (refer to --follow-symlinks option).
Exit code:
0 if no differences, 1 if differences found, 2 if error
diff --git a/tools/h5diff/testfiles/h5diff_622.txt b/tools/h5diff/testfiles/h5diff_622.txt
index 923bab5..11e2ce1 100644
--- a/tools/h5diff/testfiles/h5diff_622.txt
+++ b/tools/h5diff/testfiles/h5diff_622.txt
@@ -11,7 +11,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
-r, --report Report mode. Print differences.
-v, --verbose Verbose mode. Print differences, list of objects.
-q, --quiet Quiet mode. Do not produce output.
- --follow-links Follow symbolic links (soft links and external links)
+ --follow-symlinks Follow symbolic links (soft links and external links)
and compare the links' target objects.
If symbolic link(s) with the same name exist in the
files being compared, then determine whether the
@@ -22,13 +22,13 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
- If both symbolic links are dangling links, they
are treated as being the same; by default, h5diff
returns an exit code of 0. If, however,
- --no-dangling-links is used with --follow-links,
+ --no-dangling-links is used with --follow-symlinks,
this situation is treated as an error and h5diff
returns an exit code of 2.
- If only one of the two links is a dangling link,
they are treated as being different and h5diff
returns an exit code of 1. If, however,
- --no-dangling-links is used with --follow-links,
+ --no-dangling-links is used with --follow-symlinks,
this situation is treated as an error and h5diff
returns an exit code of 2.
- If both symbolic links point to existing objects,
@@ -36,7 +36,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
If any symbolic link specified in the call to h5diff
does not exist, h5diff treats it as an error and
returns an exit code of 2.
- --no-dangling-links Must be used with --follow-links option;
+ --no-dangling-links Must be used with --follow-symlinks option;
otherwise, h5diff shows error message and returns
an exit code of 2.
Check for any symbolic links (soft links or external
@@ -79,7 +79,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
2) groups: name string difference
3) datatypes: the return value of H5Tequal
4) links: name string difference of the linked value as default
- (refer to --follow-links option).
+ (refer to --follow-symlinks option).
Exit code:
0 if no differences, 1 if differences found, 2 if error
diff --git a/tools/h5diff/testfiles/h5diff_623.txt b/tools/h5diff/testfiles/h5diff_623.txt
index 405a211..f87d6db 100644
--- a/tools/h5diff/testfiles/h5diff_623.txt
+++ b/tools/h5diff/testfiles/h5diff_623.txt
@@ -11,7 +11,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
-r, --report Report mode. Print differences.
-v, --verbose Verbose mode. Print differences, list of objects.
-q, --quiet Quiet mode. Do not produce output.
- --follow-links Follow symbolic links (soft links and external links)
+ --follow-symlinks Follow symbolic links (soft links and external links)
and compare the links' target objects.
If symbolic link(s) with the same name exist in the
files being compared, then determine whether the
@@ -22,13 +22,13 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
- If both symbolic links are dangling links, they
are treated as being the same; by default, h5diff
returns an exit code of 0. If, however,
- --no-dangling-links is used with --follow-links,
+ --no-dangling-links is used with --follow-symlinks,
this situation is treated as an error and h5diff
returns an exit code of 2.
- If only one of the two links is a dangling link,
they are treated as being different and h5diff
returns an exit code of 1. If, however,
- --no-dangling-links is used with --follow-links,
+ --no-dangling-links is used with --follow-symlinks,
this situation is treated as an error and h5diff
returns an exit code of 2.
- If both symbolic links point to existing objects,
@@ -36,7 +36,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
If any symbolic link specified in the call to h5diff
does not exist, h5diff treats it as an error and
returns an exit code of 2.
- --no-dangling-links Must be used with --follow-links option;
+ --no-dangling-links Must be used with --follow-symlinks option;
otherwise, h5diff shows error message and returns
an exit code of 2.
Check for any symbolic links (soft links or external
@@ -79,7 +79,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
2) groups: name string difference
3) datatypes: the return value of H5Tequal
4) links: name string difference of the linked value as default
- (refer to --follow-links option).
+ (refer to --follow-symlinks option).
Exit code:
0 if no differences, 1 if differences found, 2 if error
diff --git a/tools/h5diff/testfiles/h5diff_624.txt b/tools/h5diff/testfiles/h5diff_624.txt
index dc7c83b..4c9da26 100644
--- a/tools/h5diff/testfiles/h5diff_624.txt
+++ b/tools/h5diff/testfiles/h5diff_624.txt
@@ -11,7 +11,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
-r, --report Report mode. Print differences.
-v, --verbose Verbose mode. Print differences, list of objects.
-q, --quiet Quiet mode. Do not produce output.
- --follow-links Follow symbolic links (soft links and external links)
+ --follow-symlinks Follow symbolic links (soft links and external links)
and compare the links' target objects.
If symbolic link(s) with the same name exist in the
files being compared, then determine whether the
@@ -22,13 +22,13 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
- If both symbolic links are dangling links, they
are treated as being the same; by default, h5diff
returns an exit code of 0. If, however,
- --no-dangling-links is used with --follow-links,
+ --no-dangling-links is used with --follow-symlinks,
this situation is treated as an error and h5diff
returns an exit code of 2.
- If only one of the two links is a dangling link,
they are treated as being different and h5diff
returns an exit code of 1. If, however,
- --no-dangling-links is used with --follow-links,
+ --no-dangling-links is used with --follow-symlinks,
this situation is treated as an error and h5diff
returns an exit code of 2.
- If both symbolic links point to existing objects,
@@ -36,7 +36,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
If any symbolic link specified in the call to h5diff
does not exist, h5diff treats it as an error and
returns an exit code of 2.
- --no-dangling-links Must be used with --follow-links option;
+ --no-dangling-links Must be used with --follow-symlinks option;
otherwise, h5diff shows error message and returns
an exit code of 2.
Check for any symbolic links (soft links or external
@@ -79,7 +79,7 @@ usage: h5diff [OPTIONS] file1 file2 [obj1[obj2]]
2) groups: name string difference
3) datatypes: the return value of H5Tequal
4) links: name string difference of the linked value as default
- (refer to --follow-links option).
+ (refer to --follow-symlinks option).
Exit code:
0 if no differences, 1 if differences found, 2 if error
diff --git a/tools/h5diff/testh5diff.sh b/tools/h5diff/testh5diff.sh
index 373fbfe..5bbec8d 100755
--- a/tools/h5diff/testh5diff.sh
+++ b/tools/h5diff/testh5diff.sh
@@ -26,7 +26,7 @@
# Jonathan Kim:
# Improved to use single line
# Improved to check exit code (only serial mode, not necessary for parallel)
# Added test 400 - 425 (links with --follow-links option)
# Added test 450 - 459 (dangling links)
@@ -558,125 +558,125 @@ TOOLTEST h5diff_206.txt -c $FILE2 $FILE2 g2/dset7 g2/dset8
TOOLTEST h5diff_207.txt -c $FILE2 $FILE2 g2/dset8 g2/dset9
# ##############################################################################
# # Links compare without --follow-links nor --no-dangling-links
# ##############################################################################
# test for bug1749
TOOLTEST h5diff_300.txt -v $FILE12 $FILE12 /link_g1 /link_g2
# ##############################################################################
# # Links compare with --follow-links Only
# ##############################################################################
# soft links file to file
-TOOLTEST h5diff_400.txt --follow-links -v $FILE13 $FILE13
+TOOLTEST h5diff_400.txt --follow-symlinks -v $FILE13 $FILE13
# softlink vs dset"
-TOOLTEST h5diff_401.txt --follow-links -v $FILE13 $FILE13 /softlink_dset1_1 /target_dset2
+TOOLTEST h5diff_401.txt --follow-symlinks -v $FILE13 $FILE13 /softlink_dset1_1 /target_dset2
# dset vs softlink"
-TOOLTEST h5diff_402.txt --follow-links -v $FILE13 $FILE13 /target_dset2 /softlink_dset1_1
+TOOLTEST h5diff_402.txt --follow-symlinks -v $FILE13 $FILE13 /target_dset2 /softlink_dset1_1
# softlink vs softlink"
-TOOLTEST h5diff_403.txt --follow-links -v $FILE13 $FILE13 /softlink_dset1_1 /softlink_dset2
+TOOLTEST h5diff_403.txt --follow-symlinks -v $FILE13 $FILE13 /softlink_dset1_1 /softlink_dset2
# extlink vs extlink (FILE)"
-TOOLTEST h5diff_404.txt --follow-links -v $FILE15 $FILE15
+TOOLTEST h5diff_404.txt --follow-symlinks -v $FILE15 $FILE15
# extlink vs dset"
-TOOLTEST h5diff_405.txt --follow-links -v $FILE15 $FILE16 /ext_link_dset1 /target_group2/x_dset
+TOOLTEST h5diff_405.txt --follow-symlinks -v $FILE15 $FILE16 /ext_link_dset1 /target_group2/x_dset
# dset vs extlink"
-TOOLTEST h5diff_406.txt --follow-links -v $FILE16 $FILE15 /target_group2/x_dset /ext_link_dset1
+TOOLTEST h5diff_406.txt --follow-symlinks -v $FILE16 $FILE15 /target_group2/x_dset /ext_link_dset1
# extlink vs extlink"
-TOOLTEST h5diff_407.txt --follow-links -v $FILE15 $FILE15 /ext_link_dset1 /ext_link_dset2
+TOOLTEST h5diff_407.txt --follow-symlinks -v $FILE15 $FILE15 /ext_link_dset1 /ext_link_dset2
# softlink vs extlink"
-TOOLTEST h5diff_408.txt --follow-links -v $FILE13 $FILE15 /softlink_dset1_1 /ext_link_dset2
+TOOLTEST h5diff_408.txt --follow-symlinks -v $FILE13 $FILE15 /softlink_dset1_1 /ext_link_dset2
# extlink vs softlink "
-TOOLTEST h5diff_409.txt --follow-links -v $FILE15 $FILE13 /ext_link_dset2 /softlink_dset1_1
+TOOLTEST h5diff_409.txt --follow-symlinks -v $FILE15 $FILE13 /ext_link_dset2 /softlink_dset1_1
# linked_softlink vs linked_softlink (FILE)"
-TOOLTEST h5diff_410.txt --follow-links -v $FILE14 $FILE14
+TOOLTEST h5diff_410.txt --follow-symlinks -v $FILE14 $FILE14
# dset2 vs linked_softlink_dset1"
-TOOLTEST h5diff_411.txt --follow-links -v $FILE14 $FILE14 /target_dset2 /softlink1_to_slink2
+TOOLTEST h5diff_411.txt --follow-symlinks -v $FILE14 $FILE14 /target_dset2 /softlink1_to_slink2
# linked_softlink_dset1 vs dset2"
-TOOLTEST h5diff_412.txt --follow-links -v $FILE14 $FILE14 /softlink1_to_slink2 /target_dset2
+TOOLTEST h5diff_412.txt --follow-symlinks -v $FILE14 $FILE14 /softlink1_to_slink2 /target_dset2
# linked_softlink_to_dset1 vs linked_softlink_to_dset2"
-TOOLTEST h5diff_413.txt --follow-links -v $FILE14 $FILE14 /softlink1_to_slink2 /softlink2_to_slink2
+TOOLTEST h5diff_413.txt --follow-symlinks -v $FILE14 $FILE14 /softlink1_to_slink2 /softlink2_to_slink2
# group vs linked_softlink_group1"
-TOOLTEST h5diff_414.txt --follow-links -v $FILE14 $FILE14 /target_group /softlink3_to_slink2
+TOOLTEST h5diff_414.txt --follow-symlinks -v $FILE14 $FILE14 /target_group /softlink3_to_slink2
# linked_softlink_group1 vs group"
-TOOLTEST h5diff_415.txt --follow-links -v $FILE14 $FILE14 /softlink3_to_slink2 /target_group
+TOOLTEST h5diff_415.txt --follow-symlinks -v $FILE14 $FILE14 /softlink3_to_slink2 /target_group
# linked_softlink_to_group1 vs linked_softlink_to_group2"
-TOOLTEST h5diff_416.txt --follow-links -v $FILE14 $FILE14 /softlink3_to_slink2 /softlink4_to_slink2
+TOOLTEST h5diff_416.txt --follow-symlinks -v $FILE14 $FILE14 /softlink3_to_slink2 /softlink4_to_slink2
# non-exist-softlink vs softlink"
-TOOLTEST h5diff_417.txt --follow-links -v $FILE13 $FILE13 /softlink_noexist /softlink_dset2
+TOOLTEST h5diff_417.txt --follow-symlinks -v $FILE13 $FILE13 /softlink_noexist /softlink_dset2
# softlink vs non-exist-softlink"
-TOOLTEST h5diff_418.txt --follow-links -v $FILE13 $FILE13 /softlink_dset2 /softlink_noexist
+TOOLTEST h5diff_418.txt --follow-symlinks -v $FILE13 $FILE13 /softlink_dset2 /softlink_noexist
# non-exist-extlink_file vs extlink"
-TOOLTEST h5diff_419.txt --follow-links -v $FILE15 $FILE15 /ext_link_noexist2 /ext_link_dset2
+TOOLTEST h5diff_419.txt --follow-symlinks -v $FILE15 $FILE15 /ext_link_noexist2 /ext_link_dset2
# exlink vs non-exist-extlink_file"
-TOOLTEST h5diff_420.txt --follow-links -v $FILE15 $FILE15 /ext_link_dset2 /ext_link_noexist2
+TOOLTEST h5diff_420.txt --follow-symlinks -v $FILE15 $FILE15 /ext_link_dset2 /ext_link_noexist2
# extlink vs non-exist-extlink_obj"
-TOOLTEST h5diff_421.txt --follow-links -v $FILE15 $FILE15 /ext_link_dset2 /ext_link_noexist1
+TOOLTEST h5diff_421.txt --follow-symlinks -v $FILE15 $FILE15 /ext_link_dset2 /ext_link_noexist1
# non-exist-extlink_obj vs extlink"
-TOOLTEST h5diff_422.txt --follow-links -v $FILE15 $FILE15 /ext_link_noexist1 /ext_link_dset2
+TOOLTEST h5diff_422.txt --follow-symlinks -v $FILE15 $FILE15 /ext_link_noexist1 /ext_link_dset2
# extlink_to_softlink_to_dset1 vs dset2"
-TOOLTEST h5diff_423.txt --follow-links -v $FILE17 $FILE18 /ext_link_to_slink1 /dset2
+TOOLTEST h5diff_423.txt --follow-symlinks -v $FILE17 $FILE18 /ext_link_to_slink1 /dset2
# dset2 vs extlink_to_softlink_to_dset1"
-TOOLTEST h5diff_424.txt --follow-links -v $FILE18 $FILE17 /dset2 /ext_link_to_slink1
+TOOLTEST h5diff_424.txt --follow-symlinks -v $FILE18 $FILE17 /dset2 /ext_link_to_slink1
# extlink_to_softlink_to_dset1 vs extlink_to_softlink_to_dset2"
-TOOLTEST h5diff_425.txt --follow-links -v $FILE17 $FILE17 /ext_link_to_slink1 /ext_link_to_slink2
+TOOLTEST h5diff_425.txt --follow-symlinks -v $FILE17 $FILE17 /ext_link_to_slink1 /ext_link_to_slink2
# ##############################################################################
# # Dangling links compare (--follow-links and --no-dangling-links)
# ##############################################################################
-# dangling links --follow-links (FILE to FILE)
-TOOLTEST h5diff_450.txt --follow-links -v $DANGLE_LINK_FILE1 $DANGLE_LINK_FILE2
+# dangling links --follow-symlinks (FILE to FILE)
+TOOLTEST h5diff_450.txt --follow-symlinks -v $DANGLE_LINK_FILE1 $DANGLE_LINK_FILE2
-# dangling links --follow-links and --no-dangling-links (FILE to FILE)
-TOOLTEST h5diff_451.txt --follow-links -v --no-dangling-links $DANGLE_LINK_FILE1 $DANGLE_LINK_FILE2
+# dangling links --follow-symlinks and --no-dangling-links (FILE to FILE)
+TOOLTEST h5diff_451.txt --follow-symlinks -v --no-dangling-links $DANGLE_LINK_FILE1 $DANGLE_LINK_FILE2
-# try --no-dangling-links without --follow-links options
+# try --no-dangling-links without --follow-symlinks options
TOOLTEST h5diff_452.txt --no-dangling-links $FILE13 $FILE13
# dangling link found for soft links (FILE to FILE)
-TOOLTEST h5diff_453.txt --follow-links -v --no-dangling-links $FILE13 $FILE13
+TOOLTEST h5diff_453.txt --follow-symlinks -v --no-dangling-links $FILE13 $FILE13
# dangling link found for soft links (obj to obj)
-TOOLTEST h5diff_454.txt --follow-links -v --no-dangling-links $FILE13 $FILE13 /softlink_dset2 /softlink_noexist
+TOOLTEST h5diff_454.txt --follow-symlinks -v --no-dangling-links $FILE13 $FILE13 /softlink_dset2 /softlink_noexist
# dangling link found for soft links (obj to obj) Both dangle links
-TOOLTEST h5diff_455.txt --follow-links -v --no-dangling-links $FILE13 $FILE13 /softlink_noexist /softlink_noexist
+TOOLTEST h5diff_455.txt --follow-symlinks -v --no-dangling-links $FILE13 $FILE13 /softlink_noexist /softlink_noexist
# dangling link found for ext links (FILE to FILE)
-TOOLTEST h5diff_456.txt --follow-links -v --no-dangling-links $FILE15 $FILE15
+TOOLTEST h5diff_456.txt --follow-symlinks -v --no-dangling-links $FILE15 $FILE15
# dangling link found for ext links (obj to obj). target file exist
-TOOLTEST h5diff_457.txt --follow-links -v --no-dangling-links $FILE15 $FILE15 /ext_link_dset1 /ext_link_noexist1
+TOOLTEST h5diff_457.txt --follow-symlinks -v --no-dangling-links $FILE15 $FILE15 /ext_link_dset1 /ext_link_noexist1
# dangling link found for ext links (obj to obj). target file NOT exist
-TOOLTEST h5diff_458.txt --follow-links -v --no-dangling-links $FILE15 $FILE15 /ext_link_dset1 /ext_link_noexist2
+TOOLTEST h5diff_458.txt --follow-symlinks -v --no-dangling-links $FILE15 $FILE15 /ext_link_dset1 /ext_link_noexist2
# dangling link found for ext links (obj to obj). Both dangle links
-TOOLTEST h5diff_459.txt --follow-links -v --no-dangling-links $FILE15 $FILE15 /ext_link_noexist1 /ext_link_noexist2
+TOOLTEST h5diff_459.txt --follow-symlinks -v --no-dangling-links $FILE15 $FILE15 /ext_link_noexist1 /ext_link_noexist2
# ##############################################################################
@@ -26,7 +26,7 @@
# Improved to use single line
# Improved to check exit code (only serial mode, not necessary for parallel)
-# Added test 400 - 425 (links with --follow-links option)
+# Added test 400 - 425 (links with --follow-symlinks option)
# Added test 450 - 459 (dangling links)
@@ -558,125 +558,125 @@ TOOLTEST h5diff_206.txt -c $FILE2 $FILE2 g2/dset7 g2/dset8
TOOLTEST h5diff_207.txt -c $FILE2 $FILE2 g2/dset8 g2/dset9
# ##############################################################################
-# # Links compare without --follow-links nor --no-dangling-links
+# # Links compare without --follow-symlinks nor --no-dangling-links
# ##############################################################################
# test for bug1749
@@ -558,125 +558,125 @@ TOOLTEST h5diff_206.txt -c $FILE2 $FILE2 g2/dset7 g2/dset8
TOOLTEST h5diff_300.txt -v $FILE12 $FILE12 /link_g1 /link_g2
# ##############################################################################
-# # Links compare with --follow-links Only
+# # Links compare with --follow-symlinks Only
# ##############################################################################
# soft links file to file
@@ -558,125 +558,125 @@ TOOLTEST h5diff_206.txt -c $FILE2 $FILE2 g2/dset7 g2/dset8
# ##############################################################################
-# # Dangling links compare (--follow-links and --no-dangling-links)
+# # Dangling links compare (--follow-symlinks and --no-dangling-links)
# ##############################################################################
diff --git a/tools/lib/h5diff.c b/tools/lib/h5diff.c
index 5f18ab3..c3d74b5 100644
--- a/tools/lib/h5diff.c
+++ b/tools/lib/h5diff.c
@@ -209,10 +209,10 @@ static int is_valid_options(diff_opt_t *options)
}
/* -------------------------------------------------------
* only allow --no-dangling-links along with --follow-links */
if(options->no_dangle_links && !options->follow_links)
{
- parallel_print("Error: --no-dangling-links must be used along with --follow-links option.\n");
+ parallel_print("Error: --no-dangling-links must be used along with --follow-symlinks option.\n");
options->err_stat=1;
ret = 0;
goto out;
@@ -209,10 +209,10 @@ static int is_valid_options(diff_opt_t *options)
}
/* -------------------------------------------------------
- * only allow --no-dangling-links along with --follow-links */
+ * only allow --no-dangling-links along with --follow-symlinks */
if(options->no_dangle_links && !options->follow_links)
{